@@ -64,6 +64,7 @@ def make_server(
         debug: bool = None,
         access_log: bool = None,
         loop='none',
+        shutdown_path='/stop',
         **kwargs,
 ):
     '''
@@ -115,11 +116,15 @@ def make_server(
 
     config.loaded_app = ShutdownMiddleware(config.loaded_app, server)
 
-    # Add the `stop` endpoint.
-    a = config.loaded_app
-    while not isinstance(a, Starlette):
-        a = a.app
-    a.add_route('/stop', stop_app, ['GET', 'POST'])
+    if shutdown_path is not None:
+        # Add the `stop` endpoint.
+        a = config.loaded_app
+        while not isinstance(a, Starlette):
+            a = a.app
+        for r in a.router.routes:
+            if r.path == shutdown_path:
+                raise Exception(f"path '{shutdown_path}' is alreayd used")
+        a.add_route(shutdown_path, stop_app, ['GET', 'POST'])
 
     if (config.reload or config.workers > 1) and not isinstance(app, str):
         logging.getLogger('uvicorn.error').warning(
